Skip to contents

Log summary

Usage

log_summary(
  .user_login = "EriF",
  .start,
  .end,
  .n_stocks_per_batch,
  .symbols,
  .message
)

Arguments

.user_login

Optional. A String containing the username

.start

Optional. A Date with the starting date

.end

Optional. A Date for the last day

.n_stocks_per_batch

Optional. An Integer with the number of ticker per batch

.symbols

A Vector with all the tickers

.message

A String message that has been prompted by the insert_new_data

Value

A tibble with the log

Examples

if (FALSE) { # \dontrun{
pipeline_logs <- log_summary(.symbols = symbols_vector, .message = message)
} # }