Log summary
Arguments
- .user_login
Optional. A String containing the username
- .start
Optional. A Date with the starting date
- .end
Optional. A Date for the last day
- .n_stocks_per_batch
Optional. An Integer with the number of ticker per batch
- .symbols
A Vector with all the tickers
- .message
A String message that has been prompted by the insert_new_data